marktools.get_value_of_annotation_attached_to_component
=======================================================

.. autofunction:: abjad.tools.marktools.get_value_of_annotation_attached_to_component.get_value_of_annotation_attached_to_component
